@@ -71,7 +71,7 @@ def test_resolve_did(publisher_instance, metadata):
     assert ddo['service'][1] == original['service'][1]
 
     # Can't resolve unregistered asset
-    unregistered_did = DID.did({"0": "0x00112233445566"})
+    unregistered_did = DID.encoded_did({"0": "0x00112233445566"})
     with pytest.raises(DIDNotFound):
         publisher_instance.assets.resolve(unregistered_did)
 
@@ -454,16 +454,16 @@ def test_nfts(publisher_instance, metadata):
     someone_address = "0x00a329c0648769A73afAc7F9381E08FB43dBEA72"
     ddo = publisher_instance.assets.create(metadata, publisher, cap=100, royalties=0)
 
-    balance = publisher_instance.assets.balance(publisher.address, ddo.did)
+    balance = publisher_instance.nfts.balance(publisher.address, ddo.did)
     assert balance == 0
-    balance_consumer = publisher_instance.assets.balance(someone_address, ddo.did)
+    balance_consumer = publisher_instance.nfts.balance(someone_address, ddo.did)
     assert balance_consumer == 0
 
-    publisher_instance.assets.mint(ddo.did, 10, account=publisher)
-    assert balance + 10 == publisher_instance.assets.balance(publisher.address, ddo.did)
-    assert publisher_instance.assets.transfer_nft(ddo.did, someone_address, 1, publisher)
-    assert publisher_instance.assets.balance(publisher.address, ddo.did) == 9
-    assert publisher_instance.assets.balance(someone_address, ddo.did) == balance_consumer + 1
-    publisher_instance.assets.burn(ddo.did, 9, account=publisher)
-    assert balance == publisher_instance.assets.balance(publisher.address, ddo.did)
+    publisher_instance.nfts.mint(ddo.did, 10, account=publisher)
+    assert balance + 10 == publisher_instance.nfts.balance(publisher.address, ddo.did)
+    assert publisher_instance.nfts.transfer_nft(ddo.did, someone_address, 1, publisher)
+    assert publisher_instance.nfts.balance(publisher.address, ddo.did) == 9
+    assert publisher_instance.nfts.balance(someone_address, ddo.did) == balance_consumer + 1
+    publisher_instance.nfts.burn(ddo.did, 9, account=publisher)
+    assert balance == publisher_instance.nfts.balance(publisher.address, ddo.did)
     publisher_instance.assets.retire(ddo.did)
\ No newline at end of file
